pub struct JavaConfig {
pub header_comment: HeaderComment,
pub package: Option<String>,
pub prefix: Option<String>,
pub type_mappings: HashMap<String, String>,
pub namespace_class: bool,
pub serializer: JavaSerializerOptions,
pub indent: IndentOptions,
}Fields
header_comment: HeaderCommentThe header comment to prepend to generated files
package: Option<String>Name of the Java package
prefix: Option<String>The prefix to append to user-defined types
type_mappings: HashMap<String, String>Conversions from Rust type names to Java type names
namespace_class: boolWhether generated Java classes should be wrapped in a namespace class
serializer: JavaSerializerOptionsOutput code for a specific serializer. Currently only Gson is supported.
indent: IndentOptionsDetermines the type and size of indentation.